@@ -22,7 +22,12 @@ void NumberWindow::showCard(QString txt) {
     currentText = txt;
     scene.clear();
     numberFont.setPointSize(size().height()/3);
-    QGraphicsItem * textItem = scene.addText(txt, numberFont);
+    QGraphicsItem * textItem = 0;
+    if(txt == "Coffee") {
+        textItem = scene.addPixmap(QPixmap(":/coffee.png"));
+    } else {
+        textItem = scene.addText(txt, numberFont);
+    }
     view->fitInView(textItem, Qt::KeepAspectRatio);
     showFullScreen();
 }
